# LiveKit Plugins Elevenlabs

Agent Framework plugin for voice synthesis with [ElevenLabs](https://elevenlabs.io/) API.

## Installation

```bash
pip install livekit-plugins-elevenlabs
```

## Pre-requisites

You'll need an API key from ElevenLabs. It can be set as an environment variable: `ELEVEN_API_KEY`
